rm(list=ls())
setwd("C:/Users/vries473/Werk/Projects/ETH - Local Adaptation Dianthus/Documents/Dianthus paper/New Phytologist submission/Repository/")

source("custom-functions.R")
require(data.table)
require(agricolae)
require(ggplot2)
require(RColorBrewer)
require(PerformanceAnalytics)
require(corrplot)
require(Hmisc)
require(factoextra) 
require(fpc)
require(kpeaks)
library(devtools)
library(car)
library(tidyr)
library(cowplot)
library(grid)
library(gridExtra)
library(reshape2)

################### DATA ##########################

data = read.csv("data_carth_s1_2016.csv" , header = TRUE)

data = data[data$Population %in% c("Faldumalp", "Simplonpass", "Gibidumsee", "Grengiols", "Unterstalden", "Niedergampel"),]
data$popElev = ifelse(data$Population %in% c("Faldumalp", "Simplonpass", "Gibidumsee"), "High", "Low")
data$siteElev = ifelse(data$site %in% c("Zeneggen", "Leuk"), "Low", "High")
data$env = ifelse(data$siteElev=="Low"&data$popElev=="Low", "Low", ifelse(data$siteElev=="High"&data$popElev=="High","High",ifelse(data$siteElev=="Low"&data$popElev=="High","HighLow","Other")))

data$stalkheight = data$avgstalkheight/1000

dt00 = read.csv("Home Environment.txt" , header = FALSE)

colnames(dt00) = c("sequence","population","treatment","dtemp","elevation","visits","BGComp","nitrogen","geneflow","seasonstart","seasonend","germination","death","generation","species","biomass","bioroot","bioleaf","biostem","storage","fitness","seed","maxseed","nrstalks","rosArea","realstalkheight","nrleaves","longestleaf","age","flowering","stalkheight","tbase","lignin","rlr")

dt001 = read.csv("Benign Environment.txt" , header = FALSE)

colnames(dt001) = c("sequence","population","treatment","dtemp","elevation","visits","BGComp","nitrogen","geneflow","seasonstart","seasonend","germination","death","generation","species","biomass","bioroot","bioleaf","biostem","storage","fitness","seed","maxseed","nrstalks","rosArea","realstalkheight","nrleaves","longestleaf","age","flowering","stalkheight","tbase","lignin","rlr")

cbPalette1 <- c("#999999","#0072B2","#009E73","#E69F00","#D55E00")
cbPalette2 <- c("#009E73","#D55E00","#0072B2","#F0E442", "#CC79A7")
colorscale = scale_fill_gradientn(colors = rev(brewer.pal(9, "YlGnBu")), values = c(0, exp(seq(-2, 0, length.out = 100))))

################### Calc ##########################

dt00$density = ifelse(dt00$BGComp==0,"1-low","2-high")
dt00$floweringGDD = 3500*dt00$flowering
dt00$totalbiomass = dt00$bioroot+dt00$bioleaf+dt00$biostem
dt00$ligninCont = dt00$lignin*0.25
dt00$TBase = dt00$tbase*10
dt00$ccL = 0.67 * (1-dt00$lignin*0.483)
dt00$limitation = dt00$fitness/dt00$seed
dt00$seedSink = dt00$seed-dt00$fitness
dt00$area = dt00$rosArea
dt00[is.na(dt00)] <- NA

dt001$density = ifelse(dt001$BGComp==0,"1-low","2-high")
dt001$floweringGDD = 3500*dt001$flowering
dt001$totalbiomass = dt001$bioroot+dt001$bioleaf+dt001$biostem
dt001$ligninCont = dt001$lignin*0.25
dt001$TBase = dt001$tbase*10
dt001$ccL = 0.67 * (1-dt001$lignin*0.483)
dt001$limitation = dt001$fitness/dt001$seed
dt001$seedSink = dt001$seed-dt001$fitness
dt001$area = dt001$rosArea
dt001[is.na(dt001)] <- NA

seasonlength = dt00$seasonend-dt00$seasonstart

################### CALCULATE GDD ##########################

calcT <- function(DoY,elevation,i) {
  Amp0		= c(27.3,	31.3,	21.7	);	# base amplitude of the sinois curve
  AmpE		= c(1.65,	2.1,	0.96	);	# effectof 1000m of elevation on the amplitude of the sinoid curve
  YaT			= c(15.6,	18.1,	12.1	);	# yearly average temperature
  Phase0		= c(256,	260.6,	251.8	);	# base phase of the sinoid curve       
  PhaseE		= c(4.49,	3.61,	3.56	);	# effectof 1000m of elevation on the phase of the sinoid curve
  TE			= c(5.3,	5.5,	4.71	);	# effect of 1000m of elevation on average temperature
  Tsd			= c(2.52,	3.84,	2.77	);	# standard deviation on average temperatures
  
  return  ((Amp0[i]-AmpE[i]*elevation*0.001-YaT[i])*sin((2*3.1415*1/365*DoY) +(2*3.1415*(Phase0[i]-PhaseE[i]*elevation*0.001)/365))+YaT[i]-TE[i]*elevation*0.001)
}

calcFloweringDay <- function(baseT, flowering, elevation) {
  DoY = c(1:length(flowering))
  for(i in 1:length(flowering)) {
    sumGDD = 0
    startDay = ifelse(elevation[i]==1000,18,80)
    DoY[i] = startDay
    for(d in startDay:365+startDay) {
      Temp = calcT(d,elevation[i],2)
      sumGDD = sumGDD + max(0,Temp-baseT)
      if(sumGDD<flowering[i]*3500) {
        DoY[i] = d
      } else {break}
    }
  }
  return (DoY)
}

dt00$floweringtime = calcFloweringDay(0,dt00$flowering,dt00$elevation)
dt001$floweringtime = calcFloweringDay(0,dt001$flowering,dt001$elevation)

################### FIGURE 2 ##########################

dt01 = dt00[dt00$fitness>0,]

tempLOW = dt01[dt01$elevation==1000&dt01$density=="2-high"&dt01$visits==0.3,]
tempLOW$env = "Low Elevation"
tempHIGH = dt01[dt01$elevation==2000&dt01$density=="1-low"&dt01$visits==0.03,]
tempHIGH$env = "High Elevation"

#export these for further sims
sampleLOW = sample.int(nrow(tempLOW),1000)
ex = tempLOW[sampleLOW,c("flowering","stalkheight","tbase","lignin","rlr")]
write.table(ex,file="Low populations.csv",sep=",",eol=",\r",row.names=FALSE)
sampleHIGH = sample.int(nrow(tempHIGH),1000)
ex = tempHIGH[sampleHIGH,c("flowering","stalkheight","tbase","lignin","rlr")]
write.table(ex,file="High populations.csv",sep=",",eol=",\r",row.names=FALSE)

#SCENARIO"S
dt02 = rbind(tempLOW,tempHIGH)

dt02$env = ifelse(dt02$env=="Low Elevation","Low","High")
dt02$env = factor(dt02$env, levels=c("Low","High"))
dt02$stalkheight = dt02$realstalkheight

Modelled = dt02[c("env","stalkheight","flowering","tbase","floweringtime","area","nrstalks","fitness")]

Modelled$data = "in silico"

Measured1 = data[data$env %in% c("Low","HighLow"),c("env","stalkheight","flowering","floweringtime","area","nrstalks","fitness")]
Measured2 = data[data$env %in% c("Low","High"),c("env","stalkheight","flowering","floweringtime","area","nrstalks","fitness")]
Measured3 = read.csv("Data/Germination2.csv" , header = TRUE)

Measured1$data = "in vivo"
Measured1$env = ifelse(Measured1$env == "HighLow","High",Measured1$env)
Measured2$data = "in vivo"
Measured3$env = ifelse(Measured3$pop == "H","High","Low")
Measured3$data = "in vivo"

#used for variables
dt02 = rbind(Measured2,Modelled[c("env","stalkheight","flowering","floweringtime","area","nrstalks","fitness","data")])

dt02$env = factor(dt02$env, levels=c("Low","High"))

temp1 = Modelled
temp1$trait = "SH"
temp1$traitvalue = temp1$stalkheight
temp2 = Modelled
temp2$trait = "GM"
temp2$traitvalue = temp2$tbase
temp3 = Modelled
temp3$trait = "TF"
temp3$traitvalue = temp3$flowering

temp4 = Measured1
temp4$trait = "SH"
temp4$traitvalue = temp4$stalkheight
temp5 = Measured3
temp5$trait = "GM"
temp5$traitvalue = ifelse(temp5$uG/20<1,temp5$uG/20,1)
temp6 = Measured1
temp6$trait = "TF"
temp6$traitvalue = temp6$flowering

#SINGLE DRIVERS
dt03 = rbind(temp1[temp1$traitvalue>0&is.na(temp1$traitvalue)==FALSE,c("trait","traitvalue","env","data")],
             temp2[temp2$traitvalue>0&is.na(temp2$traitvalue)==FALSE,c("trait","traitvalue","env","data")],
             temp3[temp3$traitvalue>0&is.na(temp3$traitvalue)==FALSE,c("trait","traitvalue","env","data")],
             temp4[temp4$traitvalue>0&is.na(temp4$traitvalue)==FALSE,c("trait","traitvalue","env","data")],
             temp5[temp5$traitvalue>0&is.na(temp5$traitvalue)==FALSE,c("trait","traitvalue","env","data")],
             temp6[temp6$traitvalue>0&is.na(temp6$traitvalue)==FALSE,c("trait","traitvalue","env","data")])

dt03$env = factor(dt03$env, levels=c("Low","High"))
dt02$data = factor(dt02$data, levels=c("in vivo","in silico"))

sum = summarySE(dt02, measurevar="fitness", groupvars=c("env","data"), na.rm=TRUE)

#ALL
p1  = ggplot(dt03[dt03$traitvalue>0,], aes(x=trait, y=traitvalue, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5, na.rm=TRUE) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name=paste(" Habitat","\n","elevation"),values = cbPalette2) +
  facet_wrap(~data) +
  ylim(0,1.2) +
  ylab("Trait value") +
  xlab("Trait") +
  ggtitle("a") +
  theme_cowplot() +
  theme(axis.ticks.x=element_blank(),plot.title = element_text(hjust = 0))

p1a  = ggplot(dt03[dt03$traitvalue>0&dt03$data=="in vivo",], aes(x=trait, y=traitvalue, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5, na.rm=TRUE) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name=paste(" Habitat","\n","elevation"),values = cbPalette2) +
  facet_wrap(~data) +
  ylim(0,1.2) +
  ylab("Trait value") +
  xlab("Trait") +
  ggtitle("a") +
  theme_cowplot() +
  theme(axis.ticks.x=element_blank(),plot.title = element_text(hjust = 0))

p1b  = ggplot(dt03[dt03$traitvalue>0&dt03$data=="in silico",], aes(x=trait, y=traitvalue, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5, na.rm=TRUE) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name=paste(" Habitat","\n","elevation"),values = cbPalette2) +
  facet_wrap(~data) +
  ylim(0,1.2) +
  ylab("Trait value") +
  xlab("Trait") +
  ggtitle("c") +
  theme_cowplot() +
  theme(legend.position="none",axis.ticks.x=element_blank(),plot.title = element_text(hjust = 0))

#FLOWERING
p2  = ggplot(dt02, aes(x=env, y=floweringtime, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5, na.rm=TRUE) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name=paste("Habitat","\n","elevation"),values = cbPalette2) +
  facet_wrap(~data) +
  ylab("Flowering time (DoY)") +
  xlab("") +
  ggtitle("e") +
  theme_cowplot() +
  theme(legend.position="none",plot.title = element_text(hjust = 0))

#Stalks
p3  = ggplot(dt02, aes(x=env, y=nrstalks, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5, na.rm=TRUE) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name=paste("Habitat","\n","elevation"),values = cbPalette2) +
  facet_wrap(~data) +
  ylab("Number of stalks") +
  xlab("") +
  theme_cowplot() +
  ggtitle("f") +
  theme(legend.position="none",plot.title = element_text(hjust = 0))

#BIOMASS
p4  = ggplot(dt02, aes(x=env, y=area, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5, na.rm=TRUE) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name=paste("Habitat","\n","elevation"),values = cbPalette2) +
  facet_wrap(~data) +
  ylab("Rosette area (m2)") +
  xlab("Habitat elevation") +
  theme_cowplot() +
  ggtitle("g") +
  theme(legend.position="none",plot.title = element_text(hjust = 0),axis.title.x = element_text(hjust=-4))

#FITNESS1
p5  = ggplot(dt02, aes(x=env, y=fitness, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5, na.rm=TRUE) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name=paste("Habitat","\n","elevation"),values = cbPalette2) +
  facet_wrap(~data) +
  ylab("Fitness (g)") +
  xlab("") +
  theme_cowplot() +
  ggtitle("h") +
  theme(legend.position="none",plot.title = element_text(hjust = 0))

blankPlotb <- ggplot()+theme_cowplot() + ggtitle("b")# + cowplot::theme_nothing()
blankPlotd <- ggplot()+theme_cowplot() + ggtitle("d")# + cowplot::theme_nothing()

legend <- get_legend(p1a)

p1a = p1a + theme(legend.position="none",axis.ticks.x=element_blank(),plot.title = element_text(hjust = 0))

#Previous arrangement
#grid.arrange(arrangeGrob(p1,blankPlot, widths=c(2/3, 1/3), ncol=2), arrangeGrob(p2,p3,p4,p5, widths=c(1/4, 1/4, 1/4,1/4), ncol=4),nrow=2)

#New arrangement
grid.arrange(arrangeGrob(p1a,blankPlotb, widths=c(1/3, 2/3), ncol=2), arrangeGrob(p1b,blankPlotd, widths=c(1/3, 2/3), ncol=2), arrangeGrob(p2,p3,p4,p5,legend, widths=c(2/9,2/9,2/9,2/9,1/9), ncol=5),nrow=3)


tiff("Figure 2.tiff", width = 12, height = 9, units = 'in', res = 700)
grid.arrange(arrangeGrob(p1a,blankPlotb, widths=c(1/3, 2/3), ncol=2), arrangeGrob(p1b,blankPlotd, widths=c(1/3, 2/3), ncol=2), arrangeGrob(p2,p3,p4,p5,legend, widths=c(2/9,2/9,2/9,2/9,1/9), ncol=5),nrow=3)
dev.off()

################### Figure 3 ##########################

dt3 = read.csv("Transplant.txt" , header = FALSE)

colnames(dt3) = c("sequence","population","treatment","dtemp","elevation","visits","BGComp","nitrogen","geneflow","seasonstart","seasonend","germination","death","generation","species","biomass","bioroot","bioleaf","biostem","storage","fitness","seed","maxseed","nrstalks","stalkdiameter","realstalkheight","nrleaves","longestleaf","age","flowering","stalkheight","tbase","lignin","rlr")

cbPalette1 <- c("#999999","#0072B2","#009E73","#E69F00","#D55E00")
cbPalette2 <- c("#009E73","#D55E00","#0072B2","#F0E442", "#CC79A7")
colorscale = scale_fill_gradientn(colors = rev(brewer.pal(9, "YlGnBu")), values = c(0, exp(seq(-2, 0, length.out = 100))))

dt3$floweringGDD = 3500*dt3$flowering
dt3$totalbiomass = dt3$biomass
dt3$ligninCont = dt3$lignin*0.25
dt3$TBase = dt3$tbase*10
dt3$ccL = 0.67 * (1-dt3$lignin*0.483)
dt3$N = ifelse(dt3$nitrogen==0.004,"1-rich","2-poor")
dt3$limitation = dt3$fitness/dt3$seed
dt3$seedSink = dt3$seed-dt3$fitness
dt3$treatment = ifelse(dt3$elevation==2000&dt3$BGComp==0&dt3$visits==0.03, 0, ifelse(dt3$elevation<2000&dt3$BGComp==0&dt3$visits==0.03, 1, ifelse(dt3$elevation==2000&dt3$BGComp>0&dt3$visits>0.03, 2, 3)))
dt3$plants = ifelse(dt3$species==0,"Low","High")
dt3$env = ifelse(dt3$elevation==1000&dt3$BGComp==100&dt3$visits==0.3, "Low elevation habitat", ifelse(dt3$elevation==2000&dt3$BGComp==0&dt3$visits==0.03, "High elevation habitat", "Other"))

seasonlength = dt3$seasonend-dt3$seasonstart

## CALCULATE GDD

dt0 = dt3[dt3$species==0,]
dt0$count = 1

sum0 = aggregate(dt0$count, list(seq=dt0$sequence,gen=dt0$generation,elev=dt0$elevation,comp=dt0$BGComp,pol=dt0$visits,trmt=dt0$treatment),FUN=function(x) sum(x, na.rm=FALSE))
sum0$species = "Low Elevation"

dt1 = dt3[dt3$species==1,]
dt1$count = 1

sum1 = aggregate(dt1$count, list(seq=dt1$sequence,gen=dt1$generation,elev=dt1$elevation,comp=dt1$BGComp,pol=dt1$visits,trmt=dt1$treatment),FUN=function(x) sum(x, na.rm=FALSE))
sum1$species = "High Elevation"

dt = rbind(sum0,sum1)
dt$change = ifelse(dt$trmt==2,paste(2000-dt$comp*10,"m"),paste(dt$elev,"m"))
dt$species = factor(dt$species, levels=c("Low Elevation","High Elevation"))

dt = complete(dt,nesting(seq,trmt,species,change),gen=1:10, fill = list(x=0))

#Reaction norms

sum = summarySE(dt3[dt3$fitness>0&dt3$generation==0&dt3$env %in% c("Low elevation habitat","High elevation habitat"),], measurevar="fitness", groupvars=c("plants","env"))
sum$env = ifelse(sum$env=="Low elevation habitat","Low","High")

p1  = ggplot(sum, aes(x=factor(env, levels=c("Low","High")), y=fitness, shape=factor(plants, levels=c("Low","High")), color=factor(plants, levels=c("Low","High")), group=factor(plants, levels=c("Low","High"))))+
  geom_errorbar(aes(ymin=fitness-se, ymax=fitness+se), size=0.5, width=0.1, colour="black", linetype="solid") + 
  geom_point(position=position_dodge(0), size=3) +
  geom_line(position=position_dodge(0), size=1) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_color_manual(name=paste("Plant origin","\n","elevation"),values = cbPalette2) +
  scale_shape_manual(name=paste("Plant origin","\n","elevation"),values = c(16,17)) +
  ylab("Seed production (g)") +
  xlab("Habitat elevation") +
  #ggtitle("a") +
  theme_cowplot() +
  theme(axis.ticks.x=element_blank(),plot.title = element_text(hjust = 0))

plot(p1)

tiff("Figure 3.tiff", width = 6, height = 4, units = 'in', res = 700)
plot(p1)
dev.off()

################### FIGURE 5 with a single top panel ##########################

dt01 = dt00[dt00$fitness>0,]

temp1 = dt01[dt01$elevation==1000&dt01$density=="1-low"&dt01$visits==.3,]
temp1$env = "Control"
temp2 = dt01[dt01$elevation==2000&dt01$density=="1-low"&dt01$visits==.3,]
temp2$env = "Elevation"
temp3 = dt01[dt01$elevation==1000&dt01$density=="2-high"&dt01$visits==.3,]
temp3$env = "Competition"
temp4 = dt01[dt01$elevation==1000&dt01$density=="1-low"&dt01$visits==0.03,]
temp4$env = "Pollination"

#export these for further sims
sample = sample.int(nrow(temp1),1000)
ex = temp1[sample,c("flowering","stalkheight","tbase","lignin","rlr")]
write.table(ex,file="Control populations.csv",sep=",",eol=",\r",row.names=FALSE)
sample = sample.int(nrow(temp2),1000)
ex = temp2[sample,c("flowering","stalkheight","tbase","lignin","rlr")]
write.table(ex,file="Elevation populations.csv",sep=",",eol=",\r",row.names=FALSE)
sample = sample.int(nrow(temp3),1000)
ex = temp3[sample,c("flowering","stalkheight","tbase","lignin","rlr")]
write.table(ex,file="Competition populations.csv",sep=",",eol=",\r",row.names=FALSE)
sample = sample.int(nrow(temp4),1000)
ex = temp4[sample,c("flowering","stalkheight","tbase","lignin","rlr")]
write.table(ex,file="Pollination populations.csv",sep=",",eol=",\r",row.names=FALSE)

#SINGLE DRIVERS
dt02 = rbind(temp1,temp2,temp3,temp4)

dt02$env = factor(dt02$env, levels=c("Control","Elevation","Competition","Pollination"))

#TRAITS

temp1 = dt02
temp1$trait = "SH"
temp1$traitvalue = temp1$stalkheight
temp3 = dt02
temp3$trait = "GM"
temp3$traitvalue = temp3$tbase
temp4 = dt02
temp4$trait = "TF"
temp4$traitvalue = temp4$flowering
temp5 = dt02

#SINGLE DRIVERS
dt03 = rbind(temp1,temp3,temp4)

#VARIABLES BENIGN ENV

dt01 = dt001[dt001$fitness>0,]

temp1 = dt01[dt01$species==0,]
temp1$env = "Control"
temp2 = dt01[dt01$species==1,]
temp2$env = "Elevation"
temp3 = dt01[dt01$species==2,]
temp3$env = "Competition"
temp4 = dt01[dt01$species==3,]
temp4$env = "Pollination"

#SINGLE DRIVERS
dt04 = rbind(temp1,temp2,temp3,temp4)

dt04$env = factor(dt04$env, levels=c("Control","Elevation","Competition","Pollination"))

#TRAITS
p1  = ggplot(dt03[,c("trait","traitvalue","env")], aes(x=trait, y=traitvalue, fill=factor(env)))+
  geom_boxplot(width=0.5, position=position_dodge(0.75)) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4) +
  scale_fill_manual(name="Treatment",values = cbPalette1) +
  #ylim(0,1) +
  ylab("Trait value") +
  xlab("Trait") +
  ggtitle("a") +
  theme_cowplot() +
  theme(legend.position="none",plot.title = element_text(hjust = 0))


#FLOWERING
p3  = ggplot(dt02, aes(x=env, y=floweringtime, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name="Habitat",values = cbPalette1) +
  ylab("Flowering time (DoY)") +
  xlab("") +
  ggtitle("f") +
  theme_cowplot() +
  theme(legend.position="none",plot.title = element_text(hjust = 0),axis.text.x = element_text(angle=45,vjust=1,hjust=1))

#Stalks
p4  = ggplot(dt02, aes(x=env, y=nrstalks, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name="Habitat",values = cbPalette1) +
  ylab("Number of stalks") +
  xlab("") +
  ggtitle("g") +
  theme_cowplot() +
  theme(legend.position="none",plot.title = element_text(hjust = 0),axis.text.x = element_text(angle=45,vjust=1,hjust=1))


#BIOMASS
p5  = ggplot(dt02, aes(x=env, y=area, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name="Habitat",values = cbPalette1) +
  ylab("Rosette area (m2)") +
  xlab("Treatment") +
  theme_cowplot() +
  ggtitle("h") +
  theme(legend.position="none",plot.title = element_text(hjust = 0),axis.text.x = element_text(angle=45,vjust=1,hjust=1),axis.title.x = element_text(hjust=-1))

#FITNESS
p6  = ggplot(dt02, aes(x=env, y=fitness, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name="Habitat",values = cbPalette1) +
  ylab("Fitness (g)") +
  xlab("") +
  theme_cowplot() +
  ggtitle("i") +
  theme(plot.title = element_text(hjust = 0),axis.text.x = element_text(angle=45,vjust=1,hjust=1))

#FLOWERING
p3b  = ggplot(dt04, aes(x=env, y=floweringtime, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name="Habitat",values = cbPalette1) +
  ylab("Flowering time (DoY)") +
  xlab("") +
  ggtitle("b") +
  theme_cowplot() +
  theme(legend.position="none",plot.title = element_text(hjust = 0),axis.text.x = element_text(angle=45,vjust=1,hjust=1))

#Stalks
p4b  = ggplot(dt04, aes(x=env, y=nrstalks, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name="Habitat",values = cbPalette1) +
  ylab("Number of stalks") +
  xlab("") +
  ggtitle("c") +
  theme_cowplot() +
  theme(legend.position="none",plot.title = element_text(hjust = 0),axis.text.x = element_text(angle=45,vjust=1,hjust=1))


#BIOMASS
p5b  = ggplot(dt04, aes(x=env, y=area, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name="Habitat",values = cbPalette1) +
  ylab("Rosette area (m2)") +
  xlab("Treatment") +
  theme_cowplot() +
  ggtitle("d") +
  theme(legend.position="none",plot.title = element_text(hjust = 0),axis.text.x = element_text(angle=45,vjust=1,hjust=1),axis.title.x = element_text(hjust=-1))

#FITNESS
p6b  = ggplot(dt04, aes(x=env, y=fitness, fill=factor(env)))+
  geom_boxplot(position=position_dodge(0.75), width=0.5) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4, position=position_dodge(1)) +
  scale_fill_manual(name="Habitat",values = cbPalette1) +
  ylab("Fitness (g)") +
  xlab("") +
  theme_cowplot() +
  ggtitle("e") +
  theme(legend.position="none",plot.title = element_text(hjust = 0),axis.text.x = element_text(angle=45,vjust=1,hjust=1))

legend <- get_legend(p6)

p6 = p6 + theme(legend.position="none")

grid.arrange(arrangeGrob(p1,legend, widths=c(4/5,1/5), ncol=2), arrangeGrob(p3b,p4b,p5b,p6b, widths=c(1/4, 1/4, 1/4,1/4), ncol=4), arrangeGrob(p3,p4,p5,p6, widths=c(1/4, 1/4, 1/4,1/4), ncol=4),nrow=3)

tiff("Figure 4.tiff", width = 10, height = 9, units = 'in', res = 700)
grid.arrange(arrangeGrob(p1,legend, widths=c(4/5,1/5), ncol=2), arrangeGrob(p3b,p4b,p5b,p6b, widths=c(1/4, 1/4, 1/4,1/4), ncol=4), arrangeGrob(p3,p4,p5,p6, widths=c(1/4, 1/4, 1/4,1/4), ncol=4),nrow=3)
dev.off()

################### Supplement figures ##########################

dt01 = dt00[dt00$fitness>0,]

temp1 = dt01[dt01$elevation==1000&dt01$density=="1-low"&dt01$visits==.3,]
temp1$env = "Control"
temp2 = dt01[dt01$elevation==2000&dt01$density=="1-low"&dt01$visits==.3,]
temp2$env = "Elevation"
temp3 = dt01[dt01$elevation==1000&dt01$density=="2-high"&dt01$visits==.3,]
temp3$env = "Competition"
temp4 = dt01[dt01$elevation==1000&dt01$density=="1-low"&dt01$visits==0.03,]
temp4$env = "Pollination"

#SINGLE DRIVERS
dt02 = rbind(temp1,temp2,temp3,temp4)

dt02$env = factor(dt02$env, levels=c("Control","Elevation","Competition","Pollination"))
#dt02$stalkheight = as.numeric(dt02$realstalkheight)

LM=lm(stalkheight ~ env,dt02)

anova(LM)

a = aov(tbase ~ env,dt02)
LSD.test(a,"env",console=TRUE)
a = aov(lignin ~ env,dt02)
LSD.test(a,"env",console=TRUE)
a = aov(stalkheight ~ env,dt02)
LSD.test(a,"env",console=TRUE)
a = aov(flowering ~ env,dt02)
LSD.test(a,"env",console=TRUE)

#calcualte control means for each trait
mBT = mean(dt02[dt02$env=="Control","tbase"])
mLC = mean(dt02[dt02$env=="Control","lignin"])
mSH = mean(dt02[dt02$env=="Control","stalkheight"], na.rm=TRUE)
mFT = mean(dt02[dt02$env=="Control","flowering"])

temp1 = dt02
temp1$trait = "SH"
temp1$traitvalue = ifelse(temp1$env=="Control",temp1$stalkheight,temp1$stalkheight-mSH)
temp3 = dt02
temp3$trait = "GM"
temp3$traitvalue = ifelse(temp3$env=="Control",temp3$tbase,temp3$tbase-mBT)
temp4 = dt02
temp4$trait = "TF"
temp4$traitvalue = ifelse(temp4$env=="Control",temp4$flowering,temp4$flowering-mFT)
temp5 = dt02

#SINGLE DRIVERS
dt03 = rbind(temp1,temp3,temp4)

p1  = ggplot(dt03[dt03$env=="Control"&dt03$sequence<21,], aes(x=trait, y=traitvalue, fill=as.factor(generation)))+
  geom_boxplot(width=0.5, position=position_dodge(0.75)) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4) +
  scale_fill_manual(name="Treatment",values = scales::seq_gradient_pal("white", "#999999")(seq(0,1,length.out=5))) +
  facet_grid(.~(sequence/5+1)) +
  #ylim(0,1) +
  ylab("Trait value") +
  xlab("") +
  #ggtitle("a") +
  theme_cowplot() +
  theme(legend.position="none",plot.title = element_text(hjust = 0))

plot(p1)

p2  = ggplot(dt03[dt03$env=="Control"&dt03$sequence>21,], aes(x=trait, y=traitvalue, fill=as.factor(generation)))+
  geom_boxplot(width=0.5, position=position_dodge(0.75)) +
  #geom_text(data=aggregate(traitvalue ~ trait*env, dt03[,c("trait","traitvalue","env")], mean), aes(label=round(traitvalue,2),y = traitvalue+c(0.25,0.25,-0.25,0.25,0.25)), size=4) +
  scale_fill_manual(name="Treatment",values = scales::seq_gradient_pal("white", "#999999")(seq(0,1,length.out=5))) +
  facet_grid(.~(sequence/5+1)) +
  #ylim(0,1) +
  ylab("Trait value") +
  xlab("Trait") +
  #ggtitle("a") +
  theme_cowplot() +
  theme(legend.position="none",plot.title = element_text(hjust = 0))

plot(p2)

tiff("Figure S8.tiff", width = 12, height = 8, units = 'in', res = 700)
grid.arrange(p1,p2,nrow=2)
dev.off()

mean(dt03[dt03$env=="Pollination","seedSink"])

#Storage
p0  = ggplot(dt03, aes(x=env,y=seedSink, fill=factor(env)))+
  geom_boxplot(color="black") +
  scale_fill_manual(name="Treatment",values = cbPalette1) +
  ylab("Unfilled seed mass (g)") +
  xlab("") +
  theme_cowplot() +
  theme(plot.title = element_text(hjust = 0))

plot(p0)

tiff("Figure S10.tiff", width = 6, height = 4, units = 'in', res = 700)
plot(p0)
dev.off()

## Figue S9

data2 = read.csv("Data/Germination.csv" , header = TRUE)

data2$germperc = data2$germ/data2[data2$day==30,"germ"]
data2$id = 1:56

temp = na.omit(data2[data2$germperc>=0.5,])
data3 = data2[data2$day==0,]

for(i in 1:nrow(data3)) (
  data3[i,"day"] = min(temp[temp$id==data3[i,"id"],"day"], na.rm=T)
)

data3 = na.omit(data3)

data3$rate = 1/data3$day
data3$x = paste(data3$Temp,data3$pop)
data3$Y = (data3$Temp-0)*data3$day

LM=lm(Y ~ Temp*pop,data3)

anova(LM)

#Flowering
p1  = ggplot(summarySE(data3, measurevar="Y", groupvars=c("x")), aes(x=x, y=Y)) +
  geom_bar(stat="identity") +
  geom_errorbar(aes(ymin=Y-se, ymax=Y+se), size=0.5, width=0.25, colour="black", linetype="solid") + 
  ylab("Germination time in GDD") +
  xlab("Treatment") +
  theme_cowplot() 

plot(p1)


sum = summarySE(data2, measurevar="germ", groupvars=c("day","pop","Temp"))
sum$pop = ifelse(sum$pop=="H","High","Low")
sum$pop = factor(sum$pop, levels=c("Low","High"))

p1a  = ggplot(sum[sum$Temp==20,], aes(x=day, y=germ/5, group=pop, color = pop)) +
  geom_errorbar(aes(ymin=germ/5-se/5, ymax=germ/5+se/5), width=0, colour="black", linetype="solid") + 
  stat_function(fun = function(x) (4.385/5)/(1+exp((-(6.667+(70.3344/20)) + x)/-(1.108 + 12.64/20))),size=0.75, color="black") + 
  stat_function(fun = function(x) (3.968/5)/(1+exp((-(10.1649+(70.3344/20)) + x)/-(1.108 + 12.64/20))),size=0.75, color="black") +   
  geom_line(size=0.75) +
  geom_point(size=2) +
  ylim(c(0,1)) +
  scale_color_manual(name=paste("Habitat","\n","elevation"),values = cbPalette2) +
  facet_wrap(~Temp) +
  ylab("Germnation") +
  xlab("Time (days)") +
  ggtitle("a") +
  theme_cowplot() +
  theme(legend.position="none") 

p1b  = ggplot(sum[sum$Temp==4,], aes(x=day, y=germ/5, group=pop, color = pop)) +
  geom_errorbar(aes(ymin=germ/5-se/5, ymax=germ/5+se/5), width=0, colour="black", linetype="solid") + 
  stat_function(fun = function(x) (4.385/5)/(1+exp((-(6.667+(70.3344/4)) + x)/-(1.108 + 12.64/4))),size=0.75, color="black") + 
  stat_function(fun = function(x) (3.968/5)/(1+exp((-(10.1649+(70.3344/4)) + x)/-(1.108 + 12.64/4))),size=0.75, color="black") +   
  geom_line(size=0.75) +
  geom_point(size=2) +
  ylim(c(0,1)) +
  scale_color_manual(name=paste("Habitat","\n","elevation"),values = cbPalette2) +
  facet_wrap(~Temp) +
  ylab("") +
  xlab("Time (days)") +
  ggtitle("b") +
  theme_cowplot()

legend <- get_legend(p1b)

p1b = p1b + theme(legend.position="none")

grid.arrange(arrangeGrob(p1a,p1b,legend, widths=c(3/7,3/7,1/7), ncol=3), nrow=1)

tiff("Figure S9.tiff", width = 7, height = 3, units = 'in', res = 700)
grid.arrange(arrangeGrob(p1a,p1b,legend, widths=c(3/7,3/7,1/7), ncol=3), nrow=1)
dev.off()
